==========
 nti.site
==========

.. image:: https://travis-ci.org/NextThought/nti.site.svg?branch=master
    :target: https://travis-ci.org/NextThought/nti.site

.. image:: https://coveralls.io/repos/github/NextThought/nti.site/badge.svg?branch=master
    :target: https://coveralls.io/github/NextThought/nti.site?branch=master

nti.site offers a set of classes and utility functions to integrate
non-persistent name-based configuration of components using
``z3c.baseregistry`` with persistent in-database components. These are
mixed and matched at runtime as needed to keep one "main" application
persistent site in the component lookup order.

For complete details and the changelog, see the `documentation <http://ntisite.readthedocs.io/>`_.
